[gimp] app: add the point of code removed in previous commit back in



commit fa46ef11f1c2a75170c7d2e96aa035158ea7aa81
Author: Alexia Death <alexiadeath gmail com>
Date:   Mon Dec 28 23:04:13 2015 +0200

    app: add the point of code removed in previous commit back in

 app/display/gimpdisplayshell-tool-events.c |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)
---
diff --git a/app/display/gimpdisplayshell-tool-events.c b/app/display/gimpdisplayshell-tool-events.c
index 3fc438f..8a00bc7 100644
--- a/app/display/gimpdisplayshell-tool-events.c
+++ b/app/display/gimpdisplayshell-tool-events.c
@@ -555,14 +555,17 @@ gimp_display_shell_canvas_tool_events (GtkWidget        *canvas,
               {
                 GimpCoords last_motion;
 
                 /* Use the last evaluated dynamic axes instead of the
                  * button_press event's ones because the click is
                  * usually at the same spot as the last motion event
-                 * which would give us bogus dynamics.
+                 * which would give us bogus derivate dynamics.
                  */
                 gimp_motion_buffer_begin_stroke (shell->motion_buffer, time,
                                                  &last_motion);
 
+                image_coords.velocity = last_motion.velocity;
+                image_coords.direction = last_motion.direction;
+
                 tool_manager_button_press_active (gimp,
                                                   &image_coords,
                                                   time, state,
@@ -555,14 +555,17 @@ gimp_display_shell_canvas_tool_events (GtkWidget        *canvas,
                 GimpCoords last_motion;
 
-                /* Use the last evaluated dynamic axes instead of the
+                /* Use the last evaluated velocity&direction instead of the
                  * button_press event's ones because the click is
                  * usually at the same spot as the last motion event


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]